==> humhub-1.8.0-beta.1.tar.gz: humhub-1.8.0-beta.1/protected/humhub/modules/admin/messages/de/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Information</strong>',
  '<strong>Profile</strong> Permissions' => '<strong>Profilberechtigungen</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>Einstellungen</strong> und Konfiguration',
  '<strong>User</strong> administration' => '<strong>Benutzer</strong> verwalten',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Warnung:</strong> Alle individuellen Profilberechtigungen der Benutzer werden auf die Standardeinstellungen zurückgesetzt',
  'Accept user: <strong>{displayName}</strong> ' => 'Benutzer akzeptieren: <strong>{displayName}</strong>',
  'Account' => 'Benutzerkonto',
  'Account Request for \'{displayName}\' has been approved.' => 'Zugang für \'{displayName}\' wurde genehmigt.',
  'Account Request for \'{displayName}\' has been declined.' => 'Zugang für \'{displayName}\' wurde abgelehnt.',
  'Actions' => 'Aktionen',
  'Active users' => 'Aktive Benutzer',
  'Add Groups...' => 'Gruppen hinzufügen ...',
  'Add a seperate page for the group to the directory.' => 'Füge dem Verzeichnis eine eigene Unterseite für die Gruppe hinzu.',
  'Add new category' => 'Neue Kategorie hinzufügen',
  'Add new field' => 'Neues Feld hinzufügen',
  'Add new group' => 'Neue Gruppe erstellen',
  'Add new members...' => 'Mitglieder hinzufügen ...',
  'Add new user' => 'Neuen Benutzer hinzufügen',
  'Administrator group could not be deleted!' => 'Diese Gruppe kann nicht gelöscht werden!',
  'All open registration invitations were successfully deleted.' => 'Alle ausstehenden Registrierungen wurden gelöscht.',
  'All the personal data of this user will be irrevocably deleted.' => 'Alle persönlichen Daten dieses Benutzers werden unwiderruflich gelöscht.',
  'Allow' => 'Erlauben',
  'Allow users to set individual permissions for their own profile?' => 'Erlaube Benutzern individuelle Berechtigungen für ihr eigenes Profil zu setzen?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Erlaube limitierten Zugriff auf Inhalte ohne Benutzerkonto (Zusätzliche Sichtbarkeitseinstellung: "Gast")',
  'Applied to new or existing users without any other group membership.' => 'Wird sowohl auf neue als auch auf bestehende Benutzer ohne Gruppenzugehörigkeit angewendet.',
  'Are you really sure that you want to disable this user?' => 'Bist du sicher, dass du diesen Benutzer deaktiveren möchtest?',
  'Are you really sure that you want to enable this user?' => 'Bist du sicher, dass du diesen Benutzer aktiveren möchtest?',
  'Are you really sure that you want to impersonate this user?' => 'Bist du sicher, dass du diesen Benutzer simulieren möchtest?',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Bist du dir sicher? Benutzer, die keiner anderen Gruppe zugewiesen sind, werden automatisch der Standardgruppe zugewiesen.',
  'Are you sure that you want to delete following user?' => 'Bist du sicher, dass du diesen Benutzer folgen möchtest?',
  'Cancel' => 'Abbrechen',
  'Click here to review' => 'Klicke hier, um zu überprüfen',
  'Confirm user deletion' => 'Löschen des Benutzers bestätigen',
  'Could not load category.' => 'Kann Kategorie nicht laden.',
  'Create new group' => 'Neue Gruppe erstellen',
  'Create new profile category' => 'Neue Profil-Kategorie erstellen',
  'Create new profile field' => 'Neues Profil-Feld erstellen',
  'Deactivate' => 'Deaktivieren',
  'Deactivate individual profile permissions?' => 'Individuelle Profilberechtigungen deaktivieren?',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Ablehnen &amp; Löschen des Benutzers: <strong>{displayName}</strong>',
  'Default' => 'Standard',
  'Default Profile Permissions' => 'Standard Profilberechtigungen',
  'Default content of the registration approval email' => 'Standardinhalt der Registrierungsgenehmigungs-E-Mail',
  'Default content of the registration denial email' => 'Standardinhalt der Registrierungsverweigerungs-E-Mail',
  'Default groups can not be deleted!' => 'Standard-Gruppen können nicht gelöscht werden!',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Zeitspanne, nach der ein Benutzer bei Untätigkeit automatisch abgemeldet wird (in Sekunden, optional)',
  'Default user profile visibility' => 'Standard Profilsichtbarkeit',
  'Delete' => 'Löschen',
  'Delete All' => 'Alle Löschen',
  'Delete all contributions of this user' => 'Alle Beiträge des Benutzes löschen',
  'Delete invitation' => 'Einladung löschen',
  'Delete invitation?' => 'Einladung löschen?',
  'Delete spaces which are owned by this user' => 'Spaces löschen, die im Besitz des Benutzers stehen',
  'Deleted invitation' => 'Gelöschte Einladung',
  'Deleted users' => 'Gelöschte Benutzer.',
  'Disable' => 'Deaktivieren',
  'Disabled' => 'Deaktiviert',
  'Disabled users' => 'Deaktivierte Benutzer',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Wenn die Platzhalter wie {displayName} automatisch ersetzt werden sollen, dürfen sie nicht verändert werden. Um die Email-Inhaltsfelder auf den System-Standard zurückzusetzen müssen sie einfach leer gelassen werden.',
  'Edit category' => 'Kategorie bearbeiten',
  'Edit profile category' => 'Profil-Kategorie bearbeiten',
  'Edit profile field' => 'Profil-Feld bearbeiten',
  'Edit user: {name}' => 'Benutzer editieren: {name}',
  'Enable' => 'Aktivieren',
  'Enable individual profile permissions' => 'Individuelle Profilberechtigungen aktivieren',
  'Enabled' => 'Aktiviert',
  'Group Manager' => 'Gruppenmanager',
  'Group not found!' => 'Gruppe nicht gefunden!',
  'Group user not found!' => 'Benutzer in Gruppe nicht gefunden!',
  'Groups' => 'Gruppen',
  'Hello {displayName},<br><br>
Your account has been activated.<br><br>
Click here to login:<br>
{loginLink}<br><br>

Kind Regards<br>
{AdminName}<br><br>' => 'Hallo {displayName},<br /><br /> Dein Konto wurde aktiviert.<br /><br /> Klicke hier um dich einzuloggen:<br /> {loginLink}<br /><br /> Mit freundlichen Grüßen<br /> {AdminName}<br /><br />',
  'Hello {displayName},<br><br>
Your account request has been declined.<br><br>

Kind Regards<br>
{AdminName} <br><br> ' => 'Hallo {displayName},<br /><br /> Deine Registrierungsanfrage wurde abgelehnt.<br /><br /> Mit freundlichen Grüßen<br /> {AdminName} <br /><br />',
  'Here you can create or edit profile categories and fields.' => 'Hier kannst du neue Profil-Kategorien und Felder erstellen oder bearbeiten.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Wenn individuelle Profilberechtigungen erlaubt sind, werden die folgenden Einstellungen lediglich als Standard gesetzt, den die Benutzer individuell anpassen können. Folgende, durch den Benutzer änderbare Optionen, werden zu den Profileinstellungen hinzugefügt:',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Wenn diese Option nicht ausgewählt ist, wirst du Besitzer dieses Space',
  'Impersonate' => 'Simulieren',
  'Include captcha in registration form' => 'Captcha in das Registrierungsformular aufnehmen',
  'Invite not found!' => 'Einladung nicht gefunden!',
  'Last login' => 'Letzte Anmeldung',
  'List pending registrations' => 'Liste der ausstehenden Registrierungen',
  'Make the group selectable at registration.' => 'Neue Benutzer können bereits bei der Erstellung Ihres Benutzerkontos eine Gruppe auswählen',
  'Manage group: {groupName}' => 'Gruppe verwalten: {groupName}',
  'Manage groups' => 'Gruppenverwaltung',
  'Manage profile attributes' => 'Profil-Attribute verwalten',
  'Member since' => 'Mitglied seit',
  'Members' => 'Mitglieder',
  'Members can invite external users by email' => 'Benutzer können neue Nutzer per E-Mail einladen',
  'Message' => 'Nachricht',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Minimalwert 20 Sekunden. Wenn nicht gesetzt, läuft die Sitzung nach 1400 Sekunden (24 Minuten) ab, sofern keine Aktion durch geführt wird (Standardwert für den Ablauf der Sitzung)',
  'New approval requests' => 'Neue Genehmigungsanfragen',
  'New users can register' => 'Neue Benutzer können sich registrieren',
  'No' => 'Nein',
  'No value found!' => 'Wert nicht gefunden!',
  'One or more user needs your approval as group admin.' => 'Ein oder mehrere Benutzer benötigen deine Freigabe als Gruppen Administrator.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Nur anwendbar, wenn der eingeschränkte Zugriff für nicht bestätigte Benutzer aktiviert wurde. Hat nur Auswirkungen auf neue Benutzer.',
  'Overview' => 'Übersicht',
  'Password' => 'Passwort',
  'Pending approvals' => 'Freigabe',
  'Pending user approvals' => 'Ausstehende Freigaben',
  'Permanently delete' => 'Dauerhaft gelöscht',
  'Permissions' => 'Berechtigungen',
  'Profile Permissions' => 'Profilberechtigungen',
  'Profiles' => 'Profile',
  'Remove from group' => 'Aus Gruppe entfernen',
  'Require group admin approval after registration' => 'Benötige Freigabe eines Gruppenadministrators nach Registrierung',
  'Resend invitation email' => 'Einladungs-E-Mail erneut senden',
  'Save' => 'Speichern',
  'Search by name, email or id.' => 'Suche über Name, E-Mail oder ID.',
  'Select Groups' => 'Gruppen auswählen',
  'Send & save' => 'Senden &amp; Speichern',
  'Send invitation email' => 'Einladungs-E-Mail senden',
  'Send invitation email again?' => 'Einladungs-E-Mail erneut senden?',
  'Send invite' => 'Einladung senden',
  'Send notifications to users when added to or removed from the group.' => 'Sende Benachrichtigungen an Benutzer, wenn sie der Gruppe hinzugefügt oder aus ihr entfernt werden',
  'Settings' => 'Einstellungen',
  'Show group selection at registration' => 'Gruppenauswahl bei Registrierung aktivieren',
  'Subject' => 'Betreff',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'Die Space-Mitgliedschaften aller Gruppenmitglieder werden aktualisiert. Dies kann einige Minuten in Anspruch nehmen.',
  'The following list contains all pending sign-ups and invites.' => 'Die folgende Liste enthält alle ausstehenden Registrierungen und Einladungen.',
  'The following list contains all registered users awaiting an approval.' => 'Diese Liste zeigt dir alle Benutzer an, die noch auf die Freigabe Ihres Accounts warten.',
  'The selected invitations have been successfully deleted!' => 'Die ausgewählten Einladungen wurden erfolgreich gelöscht!',
  'The user is the owner of these spaces:' => 'Der Benutzer ist Besitzer folgender Spaces:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Diese Option erlaubt es dir zu bestimmen, ob Benutzer individuelle Berechtigungen für Ihre eigenen Profile setzen dürfen.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Diese Übersicht enthält eine Liste aller registrierten Bentuzer mit der Möglichkeit, diese anzusehen, zu bearbeiten und zu löschen.',
  'This user owns no spaces.' => 'Dieser Benutzer besitzt keine Spaces.',
  'Unapproved' => 'Nicht freigegeben',
  'User deletion process queued.' => 'Der Prozess zum Löschen des Bentuzers wurde eingereiht.',
  'User is already a member of this group.' => 'Der Benutzer ist bereits Mitglied dieser Gruppe.',
  'User not found!' => 'Benutzer nicht gefunden!',
  'Users' => 'Benutzer',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Benutzer können verschiedenen Gruppen (z. B. Teams, Abteilungen etc.) mit bestimmten Standardspaces, Gruppenmanagern und Berechtigungen zugeordnet werden.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Mit dieser Option werden alle Beiträge des Benutzers (z. B. Inhalte, Kommentare oder Likes) unwiderbringlich gelöscht.',
  'View profile' => 'Profil ansehen',
  'Visible for members only' => 'Nur für Mitglieder sichtbar',
  'Visible for members+guests' => 'Für Mitglieder und Gäste sichtbar',
  'Yes' => 'Ja',
  'You can only delete empty categories!' => 'Du kannst nur leere Kategorien löschen!',
  'You cannot delete yourself!' => 'Du kannst nicht dich selber löschen!',
  'never' => 'Nie',
);

==> humhub-1.14.0-beta.1.tar.gz: humhub-1.14.0-beta.1/protected/humhub/modules/admin/messages/de/user.php <==
<?php
return array (
  '<strong>Information</strong>' => '<strong>Information</strong>',
  '<strong>Profile</strong> Permissions' => '<strong>Profilberechtigungen</strong>',
  '<strong>Settings</strong> and Configuration' => '<strong>Einstellungen</strong> und Konfiguration',
  '<strong>User</strong> administration' => '<strong>Benutzer</strong> verwalten',
  '<strong>Warning:</strong> All individual profile permission settings are reset to the default values!' => '<strong>Warnung:</strong> Alle individuellen Profilberechtigungen der Benutzer werden auf die Standardeinstellungen zurückgesetzt',
  'Accept user: <strong>{displayName}</strong> ' => 'Benutzer akzeptieren: <strong>{displayName}</strong>',
  'Account' => 'Benutzerkonto',
  'Account Request for \'{displayName}\' has been approved.' => 'Zugang für \'{displayName}\' wurde genehmigt.',
  'Account Request for \'{displayName}\' has been declined.' => 'Zugang für \'{displayName}\' wurde abgelehnt.',
  'Actions' => 'Aktionen',
  'Active users' => 'Aktive Benutzer',
  'Add Groups...' => 'Gruppen hinzufügen ...',
  'Add new category' => 'Neue Kategorie hinzufügen',
  'Add new field' => 'Neues Feld hinzufügen',
  'Add new group' => 'Neue Gruppe erstellen',
  'Add new members...' => 'Mitglieder hinzufügen ...',
  'Add new user' => 'Neuen Benutzer hinzufügen',
  'Administrator group could not be deleted!' => 'Diese Gruppe kann nicht gelöscht werden!',
  'All open registration invitations were successfully deleted.' => 'Alle ausstehenden Registrierungen wurden gelöscht.',
  'All the personal data of this user will be irrevocably deleted.' => 'Alle persönlichen Daten dieses Benutzers werden unwiderruflich gelöscht.',
  'Allow' => 'Erlauben',
  'Allow users to block each other' => 'Gegenseitiges Blockieren von Nutzern zulassen',
  'Allow users to set individual permissions for their own profile?' => 'Erlaube Benutzern individuelle Berechtigungen für ihr eigenes Profil zu setzen?',
  'Allow visitors limited access to content without an account (Adds visibility: "Guest")' => 'Erlaube limitierten Zugriff auf Inhalte ohne Benutzerkonto (Zusätzliche Sichtbarkeitseinstellung: "Gast")',
  'Applied to new or existing users without any other group membership.' => 'Wird sowohl auf neue als auch auf bestehende Benutzer ohne Gruppenzugehörigkeit angewendet.',
  'Apply' => 'Anwenden',
  'Approve' => 'Genehmigen',
  'Approve all selected' => 'Alle ausgewählten freigeben',
  'Are you really sure that you want to disable this user?' => 'Bist du sicher, dass du diesen Benutzer deaktiveren möchtest?',
  'Are you really sure that you want to enable this user?' => 'Bist du sicher, dass du diesen Benutzer aktiveren möchtest?',
  'Are you really sure that you want to impersonate this user?' => 'Bist du sicher, dass du diesen Benutzer simulieren möchtest?',
  'Are you really sure? The selected users will be approved and notified by e-mail.' => 'Bist du wirklich sicher? Alle ausgewählten Benutzer werden freigegeben und per E-Mail benachrichtigt.',
  'Are you really sure? The selected users will be deleted and notified by e-mail.' => 'Bist du wirklich sicher? Alle ausgewählten Benutzer werden gelöscht und per E-Mail benachrichtigt.',
  'Are you really sure? Users who are not assigned to another group are automatically assigned to the default group.' => 'Bist du dir sicher? Benutzer, die keiner anderen Gruppe zugewiesen sind, werden automatisch der Standardgruppe zugewiesen.',
  'Are you sure that you want to delete following user?' => 'Bist du sicher, dass du diesen Benutzer folgen möchtest?',
  'Cancel' => 'Abbrechen',
  'Click here to review' => 'Klicke hier, um zu überprüfen',
  'Confirm user deletion' => 'Löschen des Benutzers bestätigen',
  'Could not approve the user!' => 'Benutzer konnte nicht genehmigt werden!',
  'Could not decline the user!' => 'Benutzer konnte nicht abgelehnt werden!',
  'Could not load category.' => 'Kann Kategorie nicht laden.',
  'Create new group' => 'Neue Gruppe erstellen',
  'Create new profile category' => 'Neue Profil-Kategorie erstellen',
  'Create new profile field' => 'Neues Profil-Feld erstellen',
  'Deactivate' => 'Deaktivieren',
  'Deactivate individual profile permissions?' => 'Individuelle Profilberechtigungen deaktivieren?',
  'Decline' => 'Ablehnen',
  'Decline & delete user: <strong>{displayName}</strong>' => 'Ablehnen &amp; Löschen des Benutzers: <strong>{displayName}</strong>',
  'Decline all selected' => 'Alle ausgewählten ablehnen',
  'Default' => 'Standard',
  'Default Profile Permissions' => 'Standard Profilberechtigungen',
  'Default Sorting' => 'Standard Sortierung',
  'Default content of the registration approval email' => 'Standardinhalt der Registrierungsgenehmigungs-E-Mail',
  'Default content of the registration denial email' => 'Standardinhalt der Registrierungsverweigerungs-E-Mail',
  'Default group can not be deleted!' => 'Standard Gruppe darf nicht gelöscht werden!',
  'Default user idle timeout, auto-logout (in seconds, optional)' => 'Zeitspanne, nach der ein Benutzer bei Untätigkeit automatisch abgemeldet wird (in Sekunden, optional)',
  'Default user profile visibility' => 'Standard Profilsichtbarkeit',
  'Delete' => 'Löschen',
  'Delete All' => 'Alle Löschen',
  'Delete all contributions of this user' => 'Alle Beiträge des Benutzes löschen',
  'Delete invitation' => 'Einladung löschen',
  'Delete invitation?' => 'Einladung löschen?',
  'Delete spaces which are owned by this user' => 'Spaces löschen, die im Besitz des Benutzers stehen',
  'Deleted' => 'Gelöscht',
  'Deleted invitation' => 'Gelöschte Einladung',
  'Deleted users' => 'Gelöschte Benutzer.',
  'Disable' => 'Deaktivieren',
  'Disabled' => 'Deaktiviert',
  'Disabled users' => 'Deaktivierte Benutzer',
  'Do not change placeholders like {displayName} if you want them to be automatically filled by the system. To reset the email content fields with the system default, leave them empty.' => 'Wenn die Platzhalter wie {displayName} automatisch ersetzt werden sollen, dürfen sie nicht verändert werden. Um die Email-Inhaltsfelder auf den System-Standard zurückzusetzen müssen sie einfach leer gelassen werden.',
  'Edit' => 'Bearbeiten',
  'Edit category' => 'Kategorie bearbeiten',
  'Edit profile category' => 'Profil-Kategorie bearbeiten',
  'Edit profile field' => 'Profil-Feld bearbeiten',
  'Edit user: {name}' => 'Benutzer editieren: {name}',
  'Enable' => 'Aktivieren',
  'Enable individual profile permissions' => 'Individuelle Profilberechtigungen aktivieren',
  'Enabled' => 'Aktiviert',
  'First name' => 'Vorname',
  'Group Manager' => 'Gruppenmanager',
  'Group not found!' => 'Gruppe nicht gefunden!',
  'Group user not found!' => 'Benutzer in Gruppe nicht gefunden!',
  'Groups' => 'Gruppen',
  'Hello {displayName},

Your account has been activated.

Click here to login:
{loginUrl}

Kind Regards
{AdminName}

' => 'Hallo {displayName},

Dein Konto wurde aktiviert.

Klicke hier um dich einzuloggen:
{loginUrl}

Mit freundlichen Grüßen
{AdminName}',
  'Hello {displayName},

Your account request has been declined.

Kind Regards
{AdminName}

' => 'Hallo {displayName},

Deine Registrierungsanfrage wurde abgelehnt.

Mit freundlichen Grüßen
{AdminName}',
  'Here you can create or edit profile categories and fields.' => 'Hier kannst du neue Profil-Kategorien und Felder erstellen oder bearbeiten.',
  'If individual profile permissions are not allowed, the following settings are unchangeable for all users. If individual profile permissions are allowed, the settings are only set as defaults that users can customise. The following entries are then displayed in the same form in the users profile settings:' => 'Wenn individuelle Profilberechtigungen erlaubt sind, werden die folgenden Einstellungen lediglich als Standard gesetzt, den die Benutzer individuell anpassen können. Folgende, durch den Benutzer änderbare Optionen, werden zu den Profileinstellungen hinzugefügt:',
  'If this option is not selected, the ownership of the spaces will be transferred to your account.' => 'Wenn diese Option nicht ausgewählt ist, wirst du Besitzer dieses Space',
  'Impersonate' => 'Simulieren',
  'Include captcha in registration form' => 'Captcha in das Registrierungsformular aufnehmen',
  'Information 1' => 'Information I',
  'Information 2' => 'Information II',
  'Information 3' => 'Information III',
  'Invisible' => 'Unsichtbar',
  'Invite new people' => 'Neue Benutzer einladen',
  'Invite not found!' => 'Einladung nicht gefunden!',
  'Last login' => 'Zuletzt online',
  'Last name' => 'Nachname',
  'List pending registrations' => 'Liste der ausstehenden Registrierungen',
  'Make the group selectable at registration.' => 'Neue Benutzer können bereits bei der Erstellung Ihres Benutzerkontos eine Gruppe auswählen',
  'Manage group: {groupName}' => 'Gruppe verwalten: {groupName}',
  'Manage groups' => 'Gruppenverwaltung',
  'Manage profile attributes' => 'Profil-Attribute verwalten',
  'Member since' => 'Mitglied seit',
  'Members' => 'Mitglieder',
  'Members can invite external users by email' => 'Mitglieder können neue Benutzer per E-Mail einladen',
  'Members can invite external users by link' => 'Mitglieder können neue Benutzer per Link einladen',
  'Message' => 'Nachricht',
  'Min value is 20 seconds. If not set, session will timeout after 1400 seconds (24 minutes) regardless of activity (default session timeout)' => 'Minimalwert 20 Sekunden. Wenn nicht gesetzt, läuft die Sitzung nach 1400 Sekunden (24 Minuten) ab, sofern keine Aktion durch geführt wird (Standardwert für den Ablauf der Sitzung)',
  'New approval requests' => 'Neue Genehmigungsanfragen',
  'New users can register' => 'Neue Benutzer können sich registrieren',
  'No' => 'Nein',
  'No users were selected.' => 'Keine Benutzer wurden ausgewählt.',
  'No value found!' => 'Wert nicht gefunden!',
  'None' => 'Keine',
  'Not visible' => 'Nicht sichtbar',
  'One or more user needs your approval as group admin.' => 'Ein oder mehrere Benutzer benötigen deine Freigabe als Gruppen Administrator.',
  'Only applicable when limited access for non-authenticated users is enabled. Only affects new users.' => 'Nur anwendbar, wenn der eingeschränkte Zugriff für nicht bestätigte Benutzer aktiviert wurde. Hat nur Auswirkungen auf neue Benutzer.',
  'Overview' => 'Übersicht',
  'Password' => 'Passwort',
  'Pending approvals' => 'Freigabe',
  'Pending user approvals' => 'Ausstehende Freigaben',
  'People' => 'Mitgliederverzeichnis',
  'Permanently delete' => 'Dauerhaft gelöscht',
  'Permissions' => 'Berechtigungen',
  'Prioritised User Group' => 'Priorisierte Benutzergruppe',
  'Profile Permissions' => 'Profilberechtigungen',
  'Profiles' => 'Profile',
  'Protected' => 'Geschützt',
  'Protected group can not be deleted!' => 'Geschützte Gruppe darf nicht gelöscht werden.',
  'Remove from group' => 'Aus Gruppe entfernen',
  'Require group admin approval after registration' => 'Freigabeprozess für neue Benutzer aktivieren',
  'Resend invitation email' => 'Einladungs-E-Mail erneut senden',
  'Save' => 'Speichern',
  'Search by name, email or id.' => 'Suche über Name, E-Mail oder ID.',
  'Select Groups' => 'Gruppen auswählen',
  'Select a prioritised group whose members are displayed before all others when the sorting option \'Default\' is selected. The users within the group and the users outside the group are additionally sorted by their last login.' => 'Wähle eine priorisierte Benutzergruppe deren Mitglieder bei der Auswahl der Sortierung \'Standard\' vor allen anderen angezeigt werden sollen. Die Mitglieder der Gruppe und die Benutzer außerhalb der Gruppe werden zudem zusätzlich nach letztem Login sortiert.',
  'Select the profile fields you want to add as columns' => 'Wähle Profilfelder welche als Spalten hinzugefügt werden sollen.',
  'Select which user information should be displayed in the \'People\' overview. You can select any profile fields, even those you have created individually. ' => 'Bestimme welche zusätzlichen Informationen über die Mitglieder im Mitgliederverzeichnis angezeigt werden sollen. Du kannst frei aus allen Profilfeldern wählen, inbegriffen derer die du eigens angelegt hast.',
  'Send & decline' => 'Ablehnen &amp; Senden',
  'Send & save' => 'Senden &amp; Speichern',
  'Send invitation email' => 'Einladungs-E-Mail senden',
  'Send invitation email again?' => 'Einladungs-E-Mail erneut senden?',
  'Send notifications to users when added to or removed from the group.' => 'Sende Benachrichtigungen an Benutzer, wenn sie der Gruppe hinzugefügt oder aus ihr entfernt werden',
  'Settings' => 'Einstellungen',
  'Show group selection at registration' => 'Gruppenauswahl bei Registrierung aktivieren',
  'Subject' => 'Betreff',
  'The Space memberships of all group members will be updated. This may take up to several minutes.' => 'Die Space-Mitgliedschaften aller Gruppenmitglieder werden aktualisiert. Dies kann einige Minuten in Anspruch nehmen.',
  'The following list contains all pending sign-ups and invites.' => 'Die folgende Liste enthält alle ausstehenden Registrierungen und Einladungen.',
  'The following list contains all registered users awaiting an approval.' => 'Diese Liste zeigt dir alle Benutzer an, die noch auf die Freigabe Ihres Accounts warten.',
  'The registration was approved and the user was notified by email.' => 'Die Registrierung wurde freigegeben und der Benutzer per E-Mail informiert.',
  'The registration was declined and the user was notified by email.' => 'Die Registrierung wurde abgelehnt und der Benutzer per E-Mail informiert.',
  'The registrations were approved and the users were notified by email.' => 'Die Registrierungen wurden freigegben und die Benutzer per E-Mail informiert.',
  'The registrations were declined and the users were notified by email.' => 'Die Registrierungen wurden abgelehnt und die Benutzer per E-Mail informiert.',
  'The selected invitations have been successfully deleted!' => 'Die ausgewählten Einladungen wurden erfolgreich gelöscht!',
  'The user is the owner of these spaces:' => 'Der Benutzer ist Besitzer folgender Spaces:',
  'This option allows you to determine whether users may set individual permissions for their own profiles.' => 'Diese Option erlaubt es dir zu bestimmen, ob Benutzer individuelle Berechtigungen für Ihre eigenen Profile setzen dürfen.',
  'This overview contains a list of each registered user with actions to view, edit and delete users.' => 'Diese Übersicht enthält eine Liste aller registrierten Bentuzer mit der Möglichkeit, diese anzusehen, zu bearbeiten und zu löschen.',
  'This user owns no spaces.' => 'Dieser Benutzer besitzt keine Spaces.',
  'Unapproved' => 'Nicht freigegeben',
  'User deletion process queued.' => 'Der Prozess zum Löschen des Bentuzers wurde eingereiht.',
  'User is already a member of this group.' => 'Der Benutzer ist bereits Mitglied dieser Gruppe.',
  'User not found!' => 'Benutzer nicht gefunden!',
  'Users can be assigned to different groups (e.g. teams, departments etc.) with specific standard spaces, group managers and permissions.' => 'Benutzer können verschiedenen Gruppen (z. B. Teams, Abteilungen etc.) mit bestimmten Standardspaces, Gruppenmanagern und Berechtigungen zugeordnet werden.',
  'Using this option any contributions (e.g. contents, comments or likes) of this user will be irrevocably deleted.' => 'Mit dieser Option werden alle Beiträge des Benutzers (z. B. Inhalte, Kommentare oder Likes) unwiderbringlich gelöscht.',
  'View profile' => 'Profil ansehen',
  'Visible for members only' => 'Nur für Mitglieder sichtbar',
  'Visible for members+guests' => 'Für Mitglieder und Gäste sichtbar',
  'Will be used as a filter in \'People\'.' => 'Wird als Filter im Mitgliederverzeichnis verwendet.',
  'Yes' => 'Ja',
  'You can only delete empty categories!' => 'Du kannst nur leere Kategorien löschen!',
  'You cannot delete yourself!' => 'Du kannst nicht dich selber löschen!',
  'never' => 'Nie',
);
